@@ -28,7 +28,7 @@ Config::Config ()
     ListenerIp = "127.0.0.1";
     ListenerPort = 6423;
     ListenerPassword = "";
-    StatusUnit = KBYTES;
+    StatusUnit = KBITS;
     StatusFilePath = "";
     StatusFileOwner = "root";
     StatusFileGroup = "root";     
@@ -38,17 +38,24 @@ Config::Config ()
     StatusShowSum = SS_BOTTOM;
     StatusShowDoNotShape = false;
     ImqAutoRedirect = true;
+    AutoHostsBasis = "";
+    
     // Create random password
     std::string random_password_chars = "abcdefghyjklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUWXYZ1234567890";
     for (int n=0; n < 12; n++) {
         ListenerPassword += random_password_chars.at(rand() % random_password_chars.size());
     }
 
+    RunningSections.clear();
+    LocalSubnets.clear();
+
+    ProperClassesTypes.clear();
     ProperClassesTypes.push_back ("class");
     ProperClassesTypes.push_back ("class-virtual");
     ProperClassesTypes.push_back ("class-wrapper");
     ProperClassesTypes.push_back ("class-do-not-shape");
 
+    FilterTestsNeedFW.clear();
     FilterTestsNeedFW.push_back ("not-srcip");
     FilterTestsNeedFW.push_back ("not-dstip");
     FilterTestsNeedFW.push_back ("not-srcport");
@@ -113,9 +120,12 @@ std::string Config::getLine(std::ifstream &src_file)
             if ( cbuf == 35 ) potential_block_comment_tag = true;
         }
 
-        if ( cbuf == 35 ) state_store = false;  // '#'
-        if ( cbuf == 59 ) cbuf = 10;        // ';'
-        if ( cbuf == 10 ) state_store = true;   // 'NewLine'
+        if (cbuf == 35) state_store = false;    // '#'
+        if (cbuf == 59) {                       // ';'
+            if (state_store) cbuf = 10;
+            else cbuf = 35;
+        }
+        if (cbuf == 10) state_store = true;     // 'NewLine'
 
         if ( state_store && !state_block_comment)
         {
@@ -579,7 +589,7 @@ int Config::includeToFpv (std::string confdir, std::string src, EnumNsFileType t
 int Config::directiveSplit (std::string arg, std::vector < std::string > &fpv)
 {
     std::string option, param, value;
-    std::string host_section, host_iface, host_ip, host_name;
+    std::string host_header, host_section, host_iface, host_ip, host_name;
     unsigned int host_elems;
     unsigned int pos = 0;
 
@@ -596,7 +606,7 @@ int Config::directiveSplit (std::string arg, std::vector < std::string > &fpv)
     // type4 directives
     // by iteration, gets pairs of words ( parameter and value ), 
     // it's syntax error if parameter is unknown or one of pair elements is empty.
-    static char t4_src[13][17][MAX_SHORT_BUF_SIZE] = {{ "log", "file", "syslog", "terminal" },
+    static char t4_src[14][17][MAX_SHORT_BUF_SIZE] = {{ "log", "file", "syslog", "terminal" },
         { "users", "replace-classes", "download-section", "upload-section", "iface-inet", "resolve-hostname" },
         { "status", "unit", "classes", "sum", "listen", "password", "do-not-shape", "file", "owner", "group", "mode", "rewrite", "file-owner", "file-group", "file-mode", "file-rewrite" },
         { "stats",  "unit", "classes", "sum", "listen", "password", "do-not-shape", "file", "owner", "group", "mode", "rewrite", "file-owner", "file-group", "file-mode", "file-rewrite" },
@@ -608,7 +618,8 @@ int Config::directiveSplit (std::string arg, std::vector < std::string > &fpv)
         { "iptables", "download-hook", "upload-hook", "target", "imq-autoredirect" },
         { "imq", "autoredirect" },
         { "alter", "low", "ceil", "rate", "time-period" },
-        { "quota", "low", "ceil", "rate", "day", "week", "month", "file", "reset-hour", "reset-wday", "reset-mday" }};
+        { "quota", "low", "ceil", "rate", "day", "week", "month", "file", "reset-hour", "reset-wday", "reset-mday" },
+        { "auto-hosts" }};
     static char t4iface_src[5][MAX_SHORT_BUF_SIZE] = { "speed", "do-not-shape-method", "unclassified-method", "fallback-rate", "mode" };
     std::vector <std::string> t4;
     for (unsigned int i=0; i<(sizeof(t4_src)/sizeof(t4_src[0])); i++) {
@@ -661,12 +672,13 @@ int Config::directiveSplit (std::string arg, std::vector < std::string > &fpv)
 
     for (unsigned int i=0; i<=t4.size(); i++) {
         if (i == t4.size()) {
-            if ((aux::awk(option, "-", 1) != "iface") || (aux::awk(option, "-", 2).empty()) || (aux::awk(option, "-", 3).size())) break;
-            if (!ifaces->isValidSysDev(aux::awk(option, "-", 2))) { log->error(16, arg); return -1; }
+            if ((aux::awk(option, "-", 1) != "iface") || (aux::awk(option, "-", 2).empty())) break;
+            if (!ifaces->isValidSysDev(aux::trim_dev(option.substr(option.find("-")+1, std::string::npos)))) { log->error(16, arg); return -1; }
         } 
         if ((i == t4.size()) || (option == t4.at(i))) {
             if (i==t4.size()) t4.assign(t4iface_src, t4iface_src + sizeof(t4iface_src)/sizeof(t4iface_src[0]));
             else t4.assign(t4_src[i]+1, t4_src[i]+sizeof(t4_src[i])/sizeof(t4_src[i][0]));
+
             do {
                 param = aux::awk(arg, ++pos);
                 value = aux::awk(arg, ++pos);
@@ -674,11 +686,10 @@ int Config::directiveSplit (std::string arg, std::vector < std::string > &fpv)
                     log->error(24, arg);
                     return -1;
                 }
-                if (!aux::is_in_vector(t4, param)) {
+                if (!aux::is_in_vector(t4, param) && (option != "auto-hosts")) {
                     log->error(11, arg);
                     return -1;
                 }
-
                 fpv.push_back (option + " " + param + " " + value);
             } while (aux::awk(arg, pos+1).size());
             return 1;
@@ -695,19 +706,32 @@ int Config::directiveSplit (std::string arg, std::vector < std::string > &fpv)
 
     for (unsigned int n=0; n<t6host.size(); n++) {
         if (option == t6host.at(n)) {
-            host_elems = aux::awk_size(arg);
-            if ((host_elems < 5) || ((host_elems-3)%2)) { log->error(24, arg); return -1; }
-            host_ip = aux::awk(arg, host_elems-1);
-            host_name = aux::awk(arg, host_elems);
+            host_header = arg;
+            host_elems = aux::awk_size(host_header);
+            host_ip = aux::awk(host_header, host_elems-1);
+            host_name = aux::awk(host_header, host_elems);
             if (!test->validIp(host_ip)) { log->error(29, arg); return -1; }   
-            for (unsigned int m=2; m<=(host_elems-3); m++) {
-                host_section = aux::awk(arg, m);
-                host_iface = aux::awk(arg, ++m);
-                if (!aux::is_in_vector(RunningSections, host_section)) continue;
-                if (!ifaces->isValidSysDev(host_iface)) {log->error(16, arg); return -1; }   
-                fpv.push_back( "class " + host_section + " " + host_iface + " " + host_name);
-                fpv.push_back(" match _srcip-vs-dstip_ " + host_ip);
+            // Auto Host
+            if (host_elems == 3) {
+                if (aux::awk_size(AutoHostsBasis) == 0) { log->error(815, arg); return -1; }
+                host_header = "host " + AutoHostsBasis + " " + host_ip + " " + host_name;
+                host_elems = aux::awk_size(host_header);
             }
+
+            if ((host_elems < 5) || ((host_elems-3)%2)) { 
+                log->error(24, arg);
+                return -1;
+            }   
+
+            for (unsigned int m=2; m<=(host_elems-3); m++) {
+                host_section = aux::awk(host_header, m);
+                host_iface = aux::awk(host_header, ++m);
+                if (!aux::is_in_vector(RunningSections, host_section)) continue;
+                if (!ifaces->isValidSysDev(host_iface)) { log->error(16, host_header); return -1; }   
+                fpv.push_back( "class " + host_section + " " + host_iface + " " + host_name);
+                fpv.push_back(" match _auto-srcip-dstip_ " + host_ip);
+            }
+
             return 1;
         }
     }
@@ -754,3 +778,12 @@ int Config::addLocalSubnet (std::string local_subnet)
     return 0;
 }
 
+int Config::addAutoHostsBasis (std::string section, std::string iface)
+{
+    if (!AutoHostsBasis.empty()) AutoHostsBasis += " ";
+
+    AutoHostsBasis += (section + " " + iface);
+
+    return 0;
+}
+
