@@ -50,7 +50,7 @@ TcFilter::TcFilter(std::string section_name, std::string class_header, std::stri
     for (unsigned int n=2; n<=aux::awk_size(match); n++) {
         if (n >= 3) Match += " ";
 
-        if (aux::awk(match, n) == "_srcip-vs-dstip_") { 
+        if (aux::awk(match, n) == "_auto-srcip-dstip_") { 
             if (FlowDirection == DWLOAD) Match += "dstip";
             else if (FlowDirection == UPLOAD) Match += "srcip";
         }
