@@ -31,7 +31,7 @@
 Iface::Iface(int iface_index, std::string iface_name) 
 { 
     Index = iface_index; 
-    Name = iface_name; 
+    Name = aux::trim_dev(iface_name); 
     Controlled = false;
     QosInitialized = false;
     DNShapeMethodSafe = true;
@@ -46,11 +46,6 @@ Iface::Iface(int iface_index, std::string iface_name)
     sys->computeQosFilterId(0xFFF, &TcFilterU32MinId);
     sys->computeQosFilterId(0x000, &TcFilterU32MaxId);
     WAMissLastU32Used = false;
-
-    // Erase alias from iface name
-    if (Name.find_first_of(":") != std::string::npos) {
-        Name.erase(Name.find_first_of(":"));
-    }
 }
 
 Iface::~Iface()
