@@ -10,7 +10,7 @@ class Iface
 {
     friend class IfacesMap;
     public:
-        Iface(int, std::string); // ifr_ifindex, ifr_name
+        Iface(int ifr_ifindex, std::string ifr_name);
         ~Iface();
     private:
         int Index;
