@@ -494,12 +494,12 @@ int Iptables::genFilterFromNSMatch (std::string src, EnumFlowDirection class_flo
             }
             result += " -o " + filter_iface;
         }
-        else if ((param == "srcip") || ((param == "_srcip-vs-dstip_") && (class_flow_direction == UPLOAD))) {
+        else if ((param == "srcip") || ((param == "_auto-srcip-dstip_") && (class_flow_direction == UPLOAD))) {
             if (from_local_defined) { log->error(65, src); return -1; }
             if (aux::split_ip(value, addr, mask) == -1) return -1;
             result += " -s " + std::string(addr) + "/" + std::string(mask);    
         }
-        else if ((param == "dstip") || ((param == "_srcip-vs-dstip_") && (class_flow_direction == DWLOAD))) {
+        else if ((param == "dstip") || ((param == "_auto-srcip-dstip_") && (class_flow_direction == DWLOAD))) {
             if (to_local_defined) { log->error(64, src); return -1; }
             if (aux::split_ip(value, addr, mask) == -1) return -1;
             result += " -d " + std::string(addr) + "/" + std::string(mask);    
