@@ -27,19 +27,19 @@
 #include "libnetlink.h"
 
 #include "aux.h"
-#include "log.h"
+#include "logger.h"
+#include "sys.h"
 
 int
 RTNetlink::rtnl_open(rtnl_handle *rth, unsigned subscriptions)
 {
         socklen_t addr_len;
 
-        memset(rth, 0, sizeof(rth));
+        memset(rth, 0, sizeof(struct rtnl_handle));
 
         rth->fd = socket(AF_NETLINK, SOCK_RAW, NETLINK_ROUTE);
         if (rth->fd < 0) {
-                //fprintf(stderr,"Cannot open netlink socket");
-                log.error(52, "Cannot open netlink socket");
+                log->error(52, "Cannot open netlink socket");
                 return -1;
         }
 
@@ -48,24 +48,20 @@ RTNetlink::rtnl_open(rtnl_handle *rth, unsigned subscriptions)
         rth->local.nl_groups = subscriptions;
 
         if (bind(rth->fd, (struct sockaddr*)&rth->local, sizeof(rth->local)) < 0) {
-                //fprintf(stderr, "Cannot bind netlink socket");
-                log.error(52, "Cannot bind netlink socket");
+                log->error(52, "Cannot bind netlink socket");
                 return -1;
         }
         addr_len = sizeof(rth->local);
         if (getsockname(rth->fd, (struct sockaddr*)&rth->local, &addr_len) < 0) {
-                //fprintf(stderr, "Cannot getsockname");
-                log.error(52, "Cannot getsockname");
+                log->error(52, "Cannot getsockname");
                 return -1;
         }
         if (addr_len != sizeof(rth->local)) {
-                //fprintf(stderr, "Wrong address length %d\n", addr_len);
-                log.error(52, "Wrong address length " + aux::int_to_str(addr_len));
+                log->error(52, "Wrong address length " + aux::int_to_str(addr_len));
                 return -1;
         }
         if (rth->local.nl_family != AF_NETLINK) {
-                //fprintf(stderr, "Wrong address family %d\n", rth->local.nl_family);
-                log.error(52, "Wrong address family " + aux::int_to_str(rth->local.nl_family));
+                log->error(52, "Wrong address family " + aux::int_to_str(rth->local.nl_family));
                 return -1;
         }
         rth->seq = time(NULL);
@@ -113,7 +109,7 @@ RTNetlink::rtnl_send(struct rtnl_handle *rth, char *buf, int len)
 }
 
 int
-RTNetlink::rtnl_dump_request(rtnl_handle *rth, int type, void *req, int len)
+RTNetlink::rtnl_dump_request(rtnl_handle *rth, int type, void *req, size_t len)
 {
         struct nlmsghdr nlh;
         struct sockaddr_nl nladdr;
@@ -142,7 +138,8 @@ RTNetlink::rtnl_dump_filter(struct rtnl_handle *rth,
                      int (*filter)(struct sockaddr_nl *, struct nlmsghdr *n, void *),
                      void *arg1,
                      int (*junk)(struct sockaddr_nl *,struct nlmsghdr *n, void *),
-                     void *arg2)
+                     void *arg2,
+                     EnumTcObjectType qos_scope_object)
 {
         char    buf[8192];
         struct sockaddr_nl nladdr;
@@ -164,23 +161,20 @@ RTNetlink::rtnl_dump_filter(struct rtnl_handle *rth,
                 if (status < 0) {
                         if (errno == EINTR)
                                 continue;
-                        //fprintf(stderr, "OVERRUN");
-                        log.error(52, "OVERRUN");
+                        log->error(52, "OVERRUN");
                         continue;
                 }
                 if (status == 0) {
-                        //fprintf(stderr, "EOF on netlink\n");
-                        log.error(52, "EOF on netlink");
+                        log->error(52, "EOF on netlink");
                         return -1;
                 }
                 if (msg.msg_namelen != sizeof(nladdr)) {
-                        //fprintf(stderr, "sender address length == %d\n", msg.msg_namelen);
-                        //exit(1);
-                        log.error(52, "sender address length == " + aux::int_to_str(msg.msg_namelen));
+                        log->error(52, "sender address length == " + aux::int_to_str(msg.msg_namelen));
                         return -1;
                 }
 
                 h = (struct nlmsghdr*)buf;
+
                 while (NLMSG_OK(h, (size_t)status)) {
                         int err;
 
@@ -196,19 +190,23 @@ RTNetlink::rtnl_dump_filter(struct rtnl_handle *rth,
 
                         if (h->nlmsg_type == NLMSG_DONE)
                                 return 0;
+
                         if (h->nlmsg_type == NLMSG_ERROR) {
                                 struct nlmsgerr *err = (struct nlmsgerr*)NLMSG_DATA(h);
                                 if (h->nlmsg_len < NLMSG_LENGTH(sizeof(struct nlmsgerr))) {
-                                        //fprintf(stderr, "ERROR truncated\n");
-                                        log.error(52, "ERROR truncated");
+                                        log->error(52, "ERROR truncated");
                                 } else {
                                         errno = -err->error;
-                                        //fprintf(stderr, "RTNETLINK answers");
-                                        log.error(52,  "RTNETLINK answers");
+                                        log->error(52,  "RTNETLINK answers");
                                 }
                                 return -1;
                         }
-                        err = filter(&nladdr, h, arg1);
+
+                        // err = filter(&nladdr, h, arg1);
+                        if (qos_scope_object == QOS_CLASS) err = sys->qosCheckClassesBytes(&nladdr, h);
+                        else if (qos_scope_object == QOS_FILTER) err = sys->qosCheckFiltersHits(&nladdr, h);
+                        else err = -1;
+
                         if (err < 0)
                                 return err;
 
@@ -216,14 +214,11 @@ skip_it:
                         h = NLMSG_NEXT(h, status);
                 }
                 if (msg.msg_flags & MSG_TRUNC) {
-                        //fprintf(stderr, "Message truncated\n");
-                        log.error(52, "Message truncated");
+                        log->error(52, "Message truncated");
                         continue;
                 }
                 if (status) {
-                        //fprintf(stderr, "!!!Remnant of size %d\n", status);
-                        //exit(1);
-                        log.error(52, "!!!Remnant of size " + aux::int_to_str(status));
+                        log->error(52, "!!!Remnant of size " + aux::int_to_str(status));
                         return -1;
                 }
         }
@@ -260,8 +255,7 @@ RTNetlink::rtnl_talk(struct rtnl_handle *rtnl, struct nlmsghdr *n, pid_t peer,
         status = sendmsg(rtnl->fd, &msg, 0);
 
         if (status < 0) {
-                //fprintf(stderr, "Cannot talk to rtnetlink");
-                log.error(52, "Cannot talk to rtnetlink");
+                log->error(52, "Cannot talk to rtnetlink");
                 return -1;
         }
 
@@ -274,19 +268,15 @@ RTNetlink::rtnl_talk(struct rtnl_handle *rtnl, struct nlmsghdr *n, pid_t peer,
                 if (status < 0) {
                         if (errno == EINTR)
                                 continue;
-                        //fprintf(stderr, "OVERRUN");
-                        log.error(52, "OVERRUN");
+                        log->error(52, "OVERRUN");
                         continue;
                 }
                 if (status == 0) {
-                        //fprintf(stderr, "EOF on netlink\n");
-                        log.error(52, "EOF on netlink");
+                        log->error(52, "EOF on netlink");
                         return -1;
                 }
                 if (msg.msg_namelen != (int)sizeof(nladdr)) {
-                        //fprintf(stderr, "sender address length == %d\n", msg.msg_namelen);
-                        //exit(1);
-                        log.error(52, "sender address length == " + aux::int_to_str(msg.msg_namelen));
+                        log->error(52, "sender address length == " + aux::int_to_str(msg.msg_namelen));
                         return -1;
                 }
                 for (h = (struct nlmsghdr*)buf; status >= (int)sizeof(*h); ) {
@@ -296,13 +286,10 @@ RTNetlink::rtnl_talk(struct rtnl_handle *rtnl, struct nlmsghdr *n, pid_t peer,
 
                         if (l<0 || len>status) {
                                 if (msg.msg_flags & MSG_TRUNC) {
-                                        //fprintf(stderr, "Truncated message\n");
-                                        log.error(52, "Truncated message");
+                                        log->error(52, "Truncated message");
                                         return -1;
                                 }
-                                //fprintf(stderr, "!!!malformed message: len=%d\n", len);
-                                //exit(1);
-                                log.error(52, "!!!malformed message: len=" + aux::int_to_str(len));
+                                log->error(52, "!!!malformed message: len=" + aux::int_to_str(len));
                                 return -1;
                         }
 
@@ -319,8 +306,7 @@ RTNetlink::rtnl_talk(struct rtnl_handle *rtnl, struct nlmsghdr *n, pid_t peer,
                         if (h->nlmsg_type == NLMSG_ERROR) {
                                 struct nlmsgerr *err = (struct nlmsgerr*)NLMSG_DATA(h);
                                 if (l < (int)sizeof(struct nlmsgerr)) {
-                                        //fprintf(stderr, "ERROR truncated\n");
-                                        log.error(52, "ERROR truncated");
+                                        log->error(52, "ERROR truncated");
                                 } else {
                                         errno = -err->error;
                                         if (errno == 0) {
@@ -328,8 +314,7 @@ RTNetlink::rtnl_talk(struct rtnl_handle *rtnl, struct nlmsghdr *n, pid_t peer,
                                                         memcpy(answer, h, h->nlmsg_len);
                                                 return 0;
                                         }
-                                        //fprintf(stderr, "RTNETLINK answers");
-                                        log.error(52, "RTNETLINK answers");
+                                        log->error(52, "RTNETLINK answers");
                                 }
                                 return -1;
                         }
@@ -338,21 +323,17 @@ RTNetlink::rtnl_talk(struct rtnl_handle *rtnl, struct nlmsghdr *n, pid_t peer,
                                 return 0;
                         }
 
-                        //fprintf(stderr, "Unexpected reply!!!\n");
-                        log.error(52, "Unexpected reply!!!");
+                        log->error(52, "Unexpected reply!!!");
 
                         status -= NLMSG_ALIGN(len);
                         h = (struct nlmsghdr*)((char*)h + NLMSG_ALIGN(len));
                 }
                 if (msg.msg_flags & MSG_TRUNC) {
-                        //fprintf(stderr, "Message truncated\n");
-                        log.error(52, "Message truncated");
+                        log->error(52, "Message truncated");
                         continue;
                 }
                 if (status) {
-                        //fprintf(stderr, "!!!Remnant of size %d\n", status);
-                        //exit(1);
-                        log.error(52, "!!!Remnant of size " + aux::int_to_str(status));
+                        log->error(52, "!!!Remnant of size " + aux::int_to_str(status));
                         return -1;
                 }
         }
@@ -390,19 +371,15 @@ RTNetlink::rtnl_listen(struct rtnl_handle *rtnl,
                 if (status < 0) {
                         if (errno == EINTR)
                                 continue;
-                        //fprintf(stderr, "OVERRUN");
-                        log.error(52, "OVERRUN");
+                        log->error(52, "OVERRUN");
                         continue;
                 }
                 if (status == 0) {
-                        //fprintf(stderr, "EOF on netlink\n");
-                        log.error(52, "EOF on netlink");
+                        log->error(52, "EOF on netlink");
                         return -1;
                 }
                 if (msg.msg_namelen != sizeof(nladdr)) {
-                        //fprintf(stderr, "Sender address length == %d\n", msg.msg_namelen);
-                        //exit(1);
-                        log.error(52, "Sender address length == " + aux::int_to_str(msg.msg_namelen));
+                        log->error(52, "Sender address length == " + aux::int_to_str(msg.msg_namelen));
                         return -1;
                 }
                 for (h = (struct nlmsghdr*)buf; status >= (int)sizeof(*h); ) {
@@ -412,13 +389,10 @@ RTNetlink::rtnl_listen(struct rtnl_handle *rtnl,
 
                         if (l<0 || len>status) {
                                 if (msg.msg_flags & MSG_TRUNC) {
-                                        //fprintf(stderr, "Truncated message\n");
-                                        log.error(52, "Truncated message");
+                                        log->error(52, "Truncated message");
                                         return -1;
                                 }
-                                //fprintf(stderr, "!!!malformed message: len=%d\n", len);
-                                //exit(1);
-                                log.error(52, "!!!malformed message: len=" + aux::int_to_str(len));
+                                log->error(52, "!!!malformed message: len=" + aux::int_to_str(len));
                                 return -1;
                         }
 
@@ -430,21 +404,18 @@ RTNetlink::rtnl_listen(struct rtnl_handle *rtnl,
                         h = (struct nlmsghdr*)((char*)h + NLMSG_ALIGN(len));
                 }
                 if (msg.msg_flags & MSG_TRUNC) {
-                        //fprintf(stderr, "Message truncated\n");
-                        log.error(52, "Message truncated");
+                        log->error(52, "Message truncated");
                         continue;
                 }
                 if (status) {
-                        //fprintf(stderr, "!!!Remnant of size %d\n", status);
-                        //exit(1);
-                        log.error(52, "!!!Remnant of size " + aux::int_to_str(status));
+                        log->error(52, "!!!Remnant of size " + aux::int_to_str(status));
                         return -1;
                 }
         }
 }
 
 int
-RTNetlink::rtnl_ask(rtnl_handle* rtnl, struct iovec *iov, int iovlen,
+RTNetlink::rtnl_ask(rtnl_handle* rtnl, struct iovec *iov, size_t iovlen,
                                 struct rtnl_dialog *d, char *buf, int len)
 {
         int i;
@@ -464,7 +435,7 @@ RTNetlink::rtnl_ask(rtnl_handle* rtnl, struct iovec *iov, int iovlen,
         n->nlmsg_flags |= NLM_F_ACK|NLM_F_REQUEST;
         n->nlmsg_len = 0;
 
-        for (i=0; i<iovlen-1; i++) {
+        for (i=0; i<(int)iovlen-1; i++) {
                 iov[i].iov_len = NLMSG_ALIGN(iov[i].iov_len);
                 n->nlmsg_len += iov[i].iov_len;
         }
@@ -508,22 +479,19 @@ RTNetlink::rtnl_wait(rtnl_handle *rth, struct rtnl_dialog *d, int *err)
                                 return NULL;
                         }
                         if (status == 0) {
-                                //fprintf(stderr,"EOF on netlink");
-                                log.error(52, "EOF on netlink");
+                                log->error(52, "EOF on netlink");
                                 *err = -1;
                                 errno = EINVAL;
                                 return NULL;
                         }
                         if (msg.msg_namelen != sizeof(d->peer)) {
-                                //fprintf(stderr,"sender address length == %d\n", msg.msg_namelen);
-                                log.error(52, "sender address length == " + aux::int_to_str(msg.msg_namelen));
+                                log->error(52, "sender address length == " + aux::int_to_str(msg.msg_namelen));
                                 *err = -1;
                                 errno = EINVAL;
                                 return NULL;
                         }
                         if (d->peer.nl_pid) {
-                                //fprintf(stderr,"message from %d", d->peer.nl_pid);
-                                log.error(52, "message from " + aux::int_to_str(d->peer.nl_pid));
+                                log->error(52, "message from " + aux::int_to_str(d->peer.nl_pid));
                                 continue;
                         }
                         d->curlen = status;
@@ -552,16 +520,14 @@ RTNetlink::rtnl_wait(rtnl_handle *rth, struct rtnl_dialog *d, int *err)
                         if (n->nlmsg_type == NLMSG_ERROR) {
                                 struct nlmsgerr *e = (struct nlmsgerr*)NLMSG_DATA(n);
                                 if (n->nlmsg_len < NLMSG_LENGTH(sizeof(struct nlmsgerr))) {
-                                        //fprintf(stderr,"ERROR truncated");
-                                        log.error(52, "ERROR truncated");
+                                        log->error(52, "ERROR truncated");
                                         errno = EINVAL;
                                 } else if (e->error == 0) {
                                         *err = 0;
                                         return NULL;
                                 } else {
                                         errno = -e->error;
-                                        //fprintf(stderr,"RTNETLINK error: %m");
-                                        log.error(52, "RTNETLINK error: " + std::string (strerror(errno)));
+                                        log->error(52, "RTNETLINK error: " + std::string (strerror(errno)));
                                         errno = -e->error;
                                 }
                                 *err = -1;
@@ -603,7 +569,7 @@ RTNetlink::rtnl_flush(rtnl_handle *rth)
 }
 
 int
-RTNetlink::rtnl_tell_iov(rtnl_handle *rth, struct iovec *iov, int iovlen)
+RTNetlink::rtnl_tell_iov(rtnl_handle *rth, struct iovec *iov, size_t iovlen)
 {
         int err;
         char buf[4096];
@@ -630,7 +596,7 @@ RTNetlink::rtnl_tell(rtnl_handle *rth, struct nlmsghdr *n)
 }
 
 
-int
+/*int
 RTNetlink::rtnl_from_file(FILE *rtnl,
               int (*handler)(struct sockaddr_nl *,struct nlmsghdr *n, void *),
               void *jarg)
@@ -655,7 +621,7 @@ RTNetlink::rtnl_from_file(FILE *rtnl,
                         if (errno == EINTR)
                                 continue;
                         //fprintf(stderr, "rtnl_from_file: fread");
-                        log.error(52, "rtnl_from_file: fread");
+                        log->error(52, "rtnl_from_file: fread");
                         return -1;
                 }
                 if (status == 0)
@@ -667,7 +633,7 @@ RTNetlink::rtnl_from_file(FILE *rtnl,
 
                 if (l<0 || len>(int)sizeof(buf)) {
                         //fprintf(stderr, "!!!malformed message: len=%d @%lu\n", len, ftell(rtnl));
-                        log.error(52, "!!!malformed message: len=" + aux::int_to_str(len) + " @" + aux::int_to_str(ftell(rtnl)));
+                        log->error(52, "!!!malformed message: len=" + aux::int_to_str(len) + " @" + aux::int_to_str(ftell(rtnl)));
                         return -1;
                 }
 
@@ -675,12 +641,12 @@ RTNetlink::rtnl_from_file(FILE *rtnl,
 
                 if (status < 0) {
                         //fprintf(stderr, "rtnl_from_file: fread");
-                        log.error(52, "rtnl_from_file: fread");
+                        log->error(52, "rtnl_from_file: fread");
                         return -1;
                 }
                 if (status < l) {
                         //fprintf(stderr, "rtnl-from_file: truncated message\n");
-                        log.error(52,  "rtnl-from_file: truncated message");
+                        log->error(52,  "rtnl-from_file: truncated message");
                         return -1;
                 }
 
@@ -689,6 +655,7 @@ RTNetlink::rtnl_from_file(FILE *rtnl,
                         return err;
         }
 }
+*/
 
 int
 RTNetlink::addattr32(struct nlmsghdr *n, int maxlen, int type, __u32 data)
@@ -763,7 +730,6 @@ RTNetlink::parse_rtattr(struct rtattr *tb[], int max, struct rtattr *rta, int le
                 rta = RTA_NEXT(rta,len);
         }
         if (len)
-                //fprintf(stderr, "!!!Deficit %d, rta_len=%d\n", len, rta->rta_len);
-                log.error(52, "!!!Deficit " + aux::int_to_str(len) + ", rta_len=" + aux::int_to_str(rta->rta_len));
+                log->error(52, "!!!Deficit " + aux::int_to_str(len) + ", rta_len=" + aux::int_to_str(rta->rta_len));
         return 0;
 }
