@@ -49,9 +49,9 @@ std::string Logger::getErrorMessage(int mesid)
     if      (( mesid == 11 ) && ( Lang == PL_UTF8 )) message = "Nieznana dyrektywa, parametr lub wartość";
     else if (( mesid == 11 ) && ( Lang == EN )) message = "Unknown directive, parameter or value";
     else if (( mesid == 12 ) && ( Lang == PL_UTF8 )) message = "Wykryto uszkodzenie w łańcuchu iptables";
-    else if (( mesid == 12 ) && ( Lang == EN )) message = "Damage in iptables chain";
-    else if (( mesid == 13 ) && ( Lang == PL_UTF8 )) message = "Bledny reload. Parametr musi byc z zakresu 0.1s do 60s";
-    else if (( mesid == 13 ) && ( Lang == EN )) message = "Wrong reload. Must be in range: (0.1s - 60s)";
+    else if (( mesid == 12 ) && ( Lang == EN )) message = "Damage in iptables chain detected";
+    else if (( mesid == 13 ) && ( Lang == PL_UTF8 )) message = "Błędna wartość parametru reload. Parametr musi się mieścić w zakresie 0.1s do 60s";
+    else if (( mesid == 13 ) && ( Lang == EN )) message = "Wrong reload value. Must be in the range of 0.1s to 60s";
     else if (( mesid == 14 ) && ( Lang == PL_UTF8 )) message = "Błędna wartość parametru mode, poprawne to download i upload";
     else if (( mesid == 14 ) && ( Lang == EN )) message = "Wrong mode, use download or upload";
     else if (( mesid == 15 ) && ( Lang == PL_UTF8 )) message = "Brak sekcji do uruchomienia";
@@ -61,59 +61,59 @@ std::string Logger::getErrorMessage(int mesid)
     else if (( mesid == 17 ) && ( Lang == PL_UTF8 )) message = "Nie obsługiwany scheduler";
     else if (( mesid == 17 ) && ( Lang == EN )) message = "Unrecognized scheduler";
     else if (( mesid == 18 ) && ( Lang == PL_UTF8 )) message = "Błędna podsieć";
-    else if (( mesid == 18 ) && ( Lang == EN )) message = "Wrong network";
+    else if (( mesid == 18 ) && ( Lang == EN )) message = "Wrong subnet";
     else if (( mesid == 19 ) && ( Lang == PL_UTF8 )) message = "Section speed jest wymagane";
     else if (( mesid == 19 ) && ( Lang == EN )) message = "Section speed is required";    
     else if (( mesid == 20 ) && ( Lang == PL_UTF8 )) message = "Section shape jest wymagane";
     else if (( mesid == 20 ) && ( Lang == EN )) message = "Section shape is required";
     else if (( mesid == 21 ) && ( Lang == PL_UTF8 )) message = "Mode jest wymagane";
     else if (( mesid == 21 ) && ( Lang == EN )) message = "Mode is required";
-    else if (( mesid == 22 ) && ( Lang == PL_UTF8 )) message = "Przynajmniej jeden filtr sekcji jest wymagany";
-    else if (( mesid == 22 ) && ( Lang == EN )) message = "At least one section filter is required";
+    else if (( mesid == 22 ) && ( Lang == PL_UTF8 )) message = "Przynajmniej jeden filtr w klasie jest wymagany";
+    else if (( mesid == 22 ) && ( Lang == EN )) message = "At least one filter in a class is required";
     else if (( mesid == 23 ) && ( Lang == PL_UTF8 )) message = "Przynajmniej jedna klasa jest wymagana";
     else if (( mesid == 23 ) && ( Lang == EN )) message = "At least one class is required";
     else if (( mesid == 24 ) && ( Lang == PL_UTF8 )) message = "Błąd składni";
     else if (( mesid == 24 ) && ( Lang == EN )) message = "Syntax error";
-    else if (( mesid == 25 ) && ( Lang == PL_UTF8 )) message = "Zbyt dluga linia konfiguracji";
-    else if (( mesid == 25 ) && ( Lang == EN )) message = "Config line is too long";
-    else if (( mesid == 26 ) && ( Lang == PL_UTF8 )) message = "Nie mozna czytac z pliku";
-    else if (( mesid == 26 ) && ( Lang == EN )) message = "Cannot read file";
-    else if (( mesid == 27 ) && ( Lang == PL_UTF8 )) message = "Nie mozna pisac do pliku";
-    else if (( mesid == 27 ) && ( Lang == EN )) message = "Cannot write to file";
+    else if (( mesid == 25 ) && ( Lang == PL_UTF8 )) message = "Zbyt długa linia konfiguracji";
+    else if (( mesid == 25 ) && ( Lang == EN )) message = "Configuration line is too long";
+    else if (( mesid == 26 ) && ( Lang == PL_UTF8 )) message = "Nie można czytać z pliku";
+    else if (( mesid == 26 ) && ( Lang == EN )) message = "Can't read from file";
+    else if (( mesid == 27 ) && ( Lang == PL_UTF8 )) message = "Nie można pisać do pliku";
+    else if (( mesid == 27 ) && ( Lang == EN )) message = "Can't write to the file";
     else if (( mesid == 28 ) && ( Lang == PL_UTF8 )) message = "Błędne użycie parametru linii poleceń";
     else if (( mesid == 28 ) && ( Lang == EN )) message = "Command line syntax error";
-    else if (( mesid == 29 ) && ( Lang == PL_UTF8 )) message = "Błędny adres ip";
-    else if (( mesid == 29 ) && ( Lang == EN )) message = "Wrong ip address";
-    else if (( mesid == 30 ) && ( Lang == PL_UTF8 )) message = "Nie mozna bylo uruchomic sekcji";
-    else if (( mesid == 30 ) && ( Lang == EN )) message = "Cannot start section";
+    else if (( mesid == 29 ) && ( Lang == PL_UTF8 )) message = "Błędny adres IP";
+    else if (( mesid == 29 ) && ( Lang == EN )) message = "Incorrect IP address";
+    else if (( mesid == 30 ) && ( Lang == PL_UTF8 )) message = "Nie można było uruchomić sekcji";
+    else if (( mesid == 30 ) && ( Lang == EN )) message = "Can't start section";
     else if (( mesid == 31 ) && ( Lang == PL_UTF8 )) message = "Błędna jednostka transferu";
-    else if (( mesid == 31 ) && ( Lang == EN )) message = "Not proper unit";
-    else if (( mesid == 33 ) && ( Lang == PL_UTF8 )) message = "Podany interfejs nie należy do sekcji";
-    else if (( mesid == 33 ) && ( Lang == EN )) message = "Given interface is not within section";
+    else if (( mesid == 31 ) && ( Lang == EN )) message = "Wrong traffic unit";
+    else if (( mesid == 33 ) && ( Lang == PL_UTF8 )) message = "Podany interfejs sieciowy nie należy do sekcji";
+    else if (( mesid == 33 ) && ( Lang == EN )) message = "Given network interface doesn't belong to the section";
     else if (( mesid == 37 ) && ( Lang == PL_UTF8 )) message = "Filtr u32 wymaga maski sieciowej ciągłej bitowo";
     else if (( mesid == 37 ) && ( Lang == EN )) message = "Use solid netmask with u32 filter";
     else if (( mesid == 38 ) && ( Lang == PL_UTF8 )) message = "Nie odnaleziono otwarcia sekcji";
     else if (( mesid == 38 ) && ( Lang == EN )) message = "Can't find section opening tag";
     else if (( mesid == 39 ) && ( Lang == PL_UTF8 )) message = "Nie odnaleziono konfiguracji sekcji";
     else if (( mesid == 39 ) && ( Lang == EN )) message = "Can't find section configuration";
-    else if (( mesid == 40 ) && ( Lang == PL_UTF8 )) message = "Section shape jest większe od section speed";
-    else if (( mesid == 40 ) && ( Lang == EN )) message = "Section shape is bigger than section speed";
+    else if (( mesid == 40 ) && ( Lang == PL_UTF8 )) message = "Section shape nie może być większe od section speed";
+    else if (( mesid == 40 ) && ( Lang == EN )) message = "Section shape must not be bigger than section speed";
     else if (( mesid == 44 ) && ( Lang == PL_UTF8 )) message = "NiceShaper jest już uruchomiony";
     else if (( mesid == 44 ) && ( Lang == EN )) message = "NiceShaper alredy running";
     else if (( mesid == 45 ) && ( Lang == PL_UTF8 )) message = "NiceShaper nie jest uruchomiony";
     else if (( mesid == 45 ) && ( Lang == EN )) message = "NiceShaper is not running";
-    else if (( mesid == 46 ) && ( Lang == PL_UTF8 )) message = "Odczytanie pliku konfiguracyjnego nie powiodlo sie";
-    else if (( mesid == 46 ) && ( Lang == EN )) message = "Can't read config file";
-    else if (( mesid == 47 ) && ( Lang == PL_UTF8 )) message = "Odczytanie pliku klas nie powiodlo sie";
+    else if (( mesid == 46 ) && ( Lang == PL_UTF8 )) message = "Odczytanie pliku konfiguracyjnego nie powiodło sie";
+    else if (( mesid == 46 ) && ( Lang == EN )) message = "Can't read configuration file";
+    else if (( mesid == 47 ) && ( Lang == PL_UTF8 )) message = "Odczytanie pliku klas nie powiodło się";
     else if (( mesid == 47 ) && ( Lang == EN )) message = "Can't read classes file";
-    else if (( mesid == 48 ) && ( Lang == PL_UTF8 )) message = "Nie mozna utworzyć pliku";
-    else if (( mesid == 48 ) && ( Lang == EN )) message = "Cannot create file";
+    else if (( mesid == 48 ) && ( Lang == PL_UTF8 )) message = "Nie można utworzyć pliku";
+    else if (( mesid == 48 ) && ( Lang == EN )) message = "Can't create file";
     else if (( mesid == 49 ) && ( Lang == PL_UTF8 )) message = "Nawiązanie połączenia nie powiodło się";
     else if (( mesid == 49 ) && ( Lang == EN )) message = "Connection failed";
-    else if (( mesid == 50 ) && ( Lang == PL_UTF8 )) message = "Błędny port ip";
-    else if (( mesid == 50 ) && ( Lang == EN )) message = "Wrong ip port";
+    else if (( mesid == 50 ) && ( Lang == PL_UTF8 )) message = "Błędny port TCP/UDP";
+    else if (( mesid == 50 ) && ( Lang == EN )) message = "Wrong TCP/UDP port";
     else if (( mesid == 51 ) && ( Lang == PL_UTF8 )) message = "Nie udało się użyć adresu lokalnego";
-    else if (( mesid == 51 ) && ( Lang == EN )) message = "Cannot assign to address";
+    else if (( mesid == 51 ) && ( Lang == EN )) message = "Can't assign to the local address";
     else if (( mesid == 52 ) && ( Lang == PL_UTF8 )) message = "Błąd komunikacji z kernelem poprzez netlink";
     else if (( mesid == 52 ) && ( Lang == EN )) message = "Communication with kernel via netlink error";
     else if (( mesid == 53 ) && ( Lang == PL_UTF8 )) message = "Błąd wewnętrzny";
@@ -123,7 +123,7 @@ std::string Logger::getErrorMessage(int mesid)
     else if (( mesid == 55 ) && ( Lang == PL_UTF8 )) message = "Zbyt dluga nazwa klasy. Maksymalnie " + aux::int_to_str(MAX_CLASS_NAME_SIZE) +" znaków";
     else if (( mesid == 55 ) && ( Lang == EN )) message = "Class name too long. Maximum " + aux::int_to_str(MAX_CLASS_NAME_SIZE) +" chars";
     else if (( mesid == 56 ) && ( Lang == PL_UTF8 )) message = "Brak parametru, klasy nie zostaną utworzone";
-    else if (( mesid == 56 ) && ( Lang == EN )) message = "Missing parameter, not attempt to generate classess";
+    else if (( mesid == 56 ) && ( Lang == EN )) message = "Missing parameter, omit attempt to generate classess";
     else if (( mesid == 57 ) && ( Lang == PL_UTF8 )) message = "Niepoprawne hasło lub brak hasła";
     else if (( mesid == 57 ) && ( Lang == EN )) message = "Bad or missing password";
     else if (( mesid == 58 ) && ( Lang == PL_UTF8 )) message = "Parametr uruchomieniowy --remote wymaga parametru --password";
@@ -138,9 +138,9 @@ std::string Logger::getErrorMessage(int mesid)
     else if ((mesid == 62) && (Lang == PL_UTF8)) message = "Niepoprawny filtr. Test proto jest wymagany dla portów";
     else if ((mesid == 62) && (Lang == EN)) message = "Bad filter. Proto test is required to use ports";
     else if ((mesid == 64) && (Lang == PL_UTF8)) message = "Niepoprawny filtr. Test to-local wyklucza dstip";
-    else if ((mesid == 64) && (Lang == EN)) message = "Bad filter. to-local squeeze out dstip";
+    else if ((mesid == 64) && (Lang == EN)) message = "Bad filter. The to-local test squeezes out the dstip";
     else if ((mesid == 65) && (Lang == PL_UTF8)) message = "Niepoprawny filtr. Test from-local wyklucza srcip";
-    else if ((mesid == 65) && (Lang == EN)) message = "Bad filter. from-local squeeze out srcip";
+    else if ((mesid == 65) && (Lang == EN)) message = "Bad filter. The from-local test squeezes out the srcip";
     else if ((mesid == 66) && (Lang == PL_UTF8)) message = "Niepoprawny filtr. Zainicjowanie struktury U32 nie powiodło się";
     else if ((mesid == 66) && (Lang == EN)) message = "Bad filter. Prepare U32 failed";
     else if ((mesid == 67) && (Lang == PL_UTF8)) message = "Niepoprawny filtr. Błędny protokół";
@@ -148,35 +148,35 @@ std::string Logger::getErrorMessage(int mesid)
     else if ((mesid == 68) && (Lang == PL_UTF8)) message = "Niepoprawny filtr. Testy to-local oraz from-local nie mogą występować jednocześnie";
     else if ((mesid == 68) && (Lang == EN)) message = "Bad filter. Don't use to-local with from-local in the same filter";
     else if ((mesid == 69) && (Lang == PL_UTF8)) message = "Nie można wybrać poprawnego testu srcip/dstip, ze względu na brak informacji o trybie filtra (mode download/upload sekcji)";
-    else if ((mesid == 69) && (Lang == EN)) message = "Cant't choose proper srcip/dstip because of bad flow direction";
+    else if ((mesid == 69) && (Lang == EN)) message = "Cant't choose proper srcip/dstip because of unknown flow direction";
     else if ((mesid == 70) && (Lang == PL_UTF8)) message = "Niepoprawny filtr. Test to-local wymaga in-iface";
-    else if ((mesid == 70) && (Lang == EN)) message = "Bad filter. To-local test requires in-iface";
+    else if ((mesid == 70) && (Lang == EN)) message = "Bad filter. The to-local test requires the in-iface";
     else if ((mesid == 71) && (Lang == PL_UTF8)) message = "Niepoprawny filtr. Test from-local wymaga out-iface";
-    else if ((mesid == 71) && (Lang == EN)) message = "Bad filter. From-local test requires out-iface";
+    else if ((mesid == 71) && (Lang == EN)) message = "Bad filter. The from-local test requires the out-iface";
     else if ((mesid == 72) && (Lang == PL_UTF8)) message = "Niepoprawny filtr. Użycie testu in-iface w łańcuchu POSTROUTING jest niepoprawne";
     else if ((mesid == 72) && (Lang == EN)) message = "Bad filter. Using in-iface test in POSTROUTING chain is incorrect";
     else if ((mesid == 73) && (Lang == PL_UTF8)) message = "Niepoprawny filtr. Użycie testu out-iface w łańcuchu PREROUTING jest niepoprawne";
     else if ((mesid == 73) && (Lang == EN)) message = "Bad filter. Using out-iface test in PREROUTING chain is incorrect";
     else if ((mesid == 74) && (Lang == PL_UTF8)) message = "Niepoprawny filtr. Użycie interfejsu IMQ klasy wymaga wskazania interfejsu fizycznego w teście out-iface (lub in-iface dla iptables hook PREROUTING)";
     else if ((mesid == 74) && (Lang == EN)) message = "Bad filter. It's required to set physical interface in out-iface test (or in in-iface if iptables hook is PREROUTING) while using IMQ virtual interface";
-    else if ((mesid == 75) && (Lang == PL_UTF8)) message = "Niepoprawny filtr. Interfejs filtra nie może się różnić od interfejsu klasy";
-    else if ((mesid == 75) && (Lang == EN)) message = "Bad filter. Filter interface must be identical as a class interface";
-    else if ((mesid == 76) && (Lang == PL_UTF8)) message = "Niepoprawny filtr. Interfejs testu in-iface nie może być taki sam jak interfejs klasy";
-    else if ((mesid == 76) && (Lang == EN)) message = "Bad filter. In-iface test interface must not be identical as class interface";
+    else if ((mesid == 75) && (Lang == PL_UTF8)) message = "Niepoprawny filtr. Interfejs sieciowy filtra nie może się różnić od interfejsu klasy";
+    else if ((mesid == 75) && (Lang == EN)) message = "Bad filter. Filter interface must be identical as a class's network interface";
+    else if ((mesid == 76) && (Lang == PL_UTF8)) message = "Niepoprawny filtr. Interfejs sieciowy testu in-iface nie może być taki sam jak interfejs klasy";
+    else if ((mesid == 76) && (Lang == EN)) message = "Bad filter. The in-iface test interface must not be identical to the class interface";
     // General configuration messages
     else if ((mesid == 101) && ( Lang == PL_UTF8 )) message = "Nieznany parametr lub wartość";
     else if ((mesid == 101) && ( Lang == EN )) message = "Unknown parameter or value";
     else if ((mesid == 102) && ( Lang == PL_UTF8 )) message = "Niepoprawna wartość parametru";
     else if ((mesid == 102) && ( Lang == EN )) message = "Bad value";
-    else if ((mesid == 103) && ( Lang == PL_UTF8 )) message = "Klasy typu do-not-shape oraz wrapper wymagają parametru iface-<iface> speed";
-    else if ((mesid == 103) && ( Lang == EN )) message = "Classess do-not-shape and wrapper type requires iface-<iface> speed parameter";
+    else if ((mesid == 103) && ( Lang == PL_UTF8 )) message = "Klasy typu do-not-shape oraz wrapper wymagają parametru iface-<dev> speed";
+    else if ((mesid == 103) && ( Lang == EN )) message = "Classes do-not-shape and wrapper types require iface-<dev> speed";
     else if ((mesid == 104) && ( Lang == PL_UTF8 )) message = "Nazwa dyrektywy user musi zostać zamieniona na host";
     else if ((mesid == 104) && ( Lang == EN )) message = "The name of the user directive needs to be changed to host";
     // Deprecated options
     else if ((mesid == 150) && ( Lang == PL_UTF8 )) message = "Podana opcja jest przestarzała, użyj iptables imq-autoredirect [yes|no]";
     else if ((mesid == 150) && ( Lang == EN )) message = "Given option is deprecated, use iptables imq-autoredirect [true|false]";
     else if ((mesid == 151) && ( Lang == PL_UTF8 )) message = "Podana opcja została przeniesiona do sekcji global";
-    else if ((mesid == 151) && ( Lang == EN )) message = "Given option is moved to section global";
+    else if ((mesid == 151) && ( Lang == EN )) message = "Given option is moved to global section";
     else if ((mesid == 152) && ( Lang == PL_UTF8 )) message = "Podana opcja jest przestarzała, użyj odpowiedniego nagłówka klasy";
     else if ((mesid == 152) && ( Lang == EN )) message = "Given option is deprecated, use proper class header";
     else if ((mesid == 153) && ( Lang == PL_UTF8 )) message = "Opcje status listen oraz stats listen zostały wycofane, użyj listen address";
@@ -188,8 +188,8 @@ std::string Logger::getErrorMessage(int mesid)
     else if ((mesid == 158) && (Lang == PL_UTF8)) message = "Parametr usunięty w wersji 1.2rc1";
     else if ((mesid == 158) && (Lang == EN)) message = "Parameter is removed from version 1.2rc1";
     // Filesystem operations
-    else if ((mesid == 201) && ( Lang == PL_UTF8 )) message = "Nie mozna otworzyć pliku";
-    else if ((mesid == 201) && ( Lang == EN )) message = "Cannot open file";
+    else if ((mesid == 201) && ( Lang == PL_UTF8 )) message = "Nie można otworzyć pliku";
+    else if ((mesid == 201) && ( Lang == EN )) message = "Can't open file";
     // Inter processess and network communication
     else if ((mesid == 301) && ( Lang == PL_UTF8 )) message = "Przyjęcie połączenia sieciowego zakończone niepowodzeniem";
     else if ((mesid == 301) && ( Lang == EN )) message = "Accepting connection on a socket failed";
@@ -217,8 +217,8 @@ std::string Logger::getErrorMessage(int mesid)
     else if ((mesid == 406) && ( Lang == PL_UTF8 )) message = "Utworzenie mutexa dla sterowania wątkami zakończone niepowodzeniem. Poważny problem systemu operacyjnego";
     else if ((mesid == 406) && ( Lang == EN )) message = "Threads Control Mutex init failed. Serious system problem";
     // QOS
-    else if ((mesid == 501) && ( Lang == PL_UTF8 )) message = "Uszkodzenie w strukturze HTB";
-    else if ((mesid == 501) && ( Lang == EN )) message = "Damage in HTB framework";
+    else if ((mesid == 501) && ( Lang == PL_UTF8 )) message = "Wykryto szkodzenie w strukturze HTB";
+    else if ((mesid == 501) && ( Lang == EN )) message = "Damage in HTB framework detected";
     else if ((mesid == 502) && ( Lang == PL_UTF8 )) message = "Napotkano brak opcji performance counters filtrów U32 (CONFIG_CLS_U32_PERF) w uruchomionym kernelu. Zamiennie użyte zostaną filtry iptables, jednak, rekonfiguracja kernela jest zalecanym rozwiązaniem";
     else if ((mesid == 502) && ( Lang == EN )) message = "Performance counters support for U32 filters (CONFIG_CLS_U32_PERF) is probably missing. Iptables rules will be used instead, however, kernel reconfiguration is recommended";
     else if ((mesid == 503) && ( Lang == PL_UTF8 )) message = "Najprawdopodobniej napotkano błąd kernela 3.14 (i kilku następnych), uniemożliwiający odczytanie ostatniego filtra U32 w kompilacji x86. Nastąpi próba obejścia problemu";
@@ -242,17 +242,17 @@ std::string Logger::getErrorMessage(int mesid)
     else if ((mesid == 801) && (Lang == PL_UTF8)) message = "Niepoprawna wartość alter time-period";
     else if ((mesid == 801) && (Lang == EN)) message = "Bad alter time-period value";
     else if ((mesid == 802) && (Lang == PL_UTF8)) message = "Burst sekcji musi być większe lub równe największemu burst klas podległych";
-    else if ((mesid == 802) && (Lang == EN)) message = "Section burst must be equal or bigger than its classes biggest burst value";
+    else if ((mesid == 802) && (Lang == EN)) message = "Section burst must be equal or bigger than it's classes biggest burst value";
     else if ((mesid == 803) && (Lang == PL_UTF8)) message = "Suma wartości parametrów section speed, jest większa lub równa zadeklarowanej szybkości interfejsu";
-    else if ((mesid == 803) && (Lang == EN)) message = "Sections speeds sum bigger or equal than declared iface speed";
+    else if ((mesid == 803) && (Lang == EN)) message = "Sections speeds sum greater or equal than declared iface speed";
     else if ((mesid == 804) && (Lang == PL_UTF8)) message = "Suma wartości parametrów section speed oraz fallback-rate, jest większa lub równa zadeklarowanej szybkości interfejsu";
-    else if ((mesid == 804) && (Lang == EN)) message = "Sections speeds sum and fallback-rate bigger or equal than declared iface speed";
+    else if ((mesid == 804) && (Lang == EN)) message = "Sections speeds sum and fallback-rate greater or equal than declared iface speed";
     else if ((mesid == 805) && (Lang == PL_UTF8)) message = "Błędna wartość parametru status rewrite. Parametr musi byc z zakresu 1s do 3600s";
     else if ((mesid == 805) && (Lang == EN)) message = "Wrong status rewrite value. Must be in range of 1s to 3600s";
     else if ((mesid == 806) && (Lang == PL_UTF8)) message = "Wartość nie może być wyższa od " + aux::int_to_str(aux::unit_convert(MAX_RATE, MBITS)) + aux::unit_to_str(MBITS, 0) + " ani niższa od " + aux::int_to_str(aux::unit_convert(MIN_RATE, BITS)) + aux::unit_to_str(BITS, 0);
-    else if ((mesid == 806) && (Lang == EN)) message = "Value cannot be bigger than " + aux::int_to_str(aux::unit_convert(MAX_RATE, MBITS)) + aux::unit_to_str(MBITS, 0) + " or less than " + aux::int_to_str(aux::unit_convert(MIN_RATE, BITS)) + aux::unit_to_str(BITS, 0);
+    else if ((mesid == 806) && (Lang == EN)) message = "Value cannot be greater than " + aux::int_to_str(aux::unit_convert(MAX_RATE, MBITS)) + aux::unit_to_str(MBITS, 0) + " or less than " + aux::int_to_str(aux::unit_convert(MIN_RATE, BITS)) + aux::unit_to_str(BITS, 0);
     else if ((mesid == 807) && (Lang == PL_UTF8)) message = "Strict musi się mieścić w przedziale 0 do 100";
-    else if ((mesid == 807) && (Lang == EN)) message = "Strict must be a value between 0 to 100";
+    else if ((mesid == 807) && (Lang == EN)) message = "Strict has to be a value in the range of 0 to 100";
     else if ((mesid == 808) && (Lang == PL_UTF8)) message = "Brak zdefiniowanych podsieci - brak dyrektywy local-subnets";
     else if ((mesid == 808) && (Lang == EN)) message = "Missing local subnets, local-subnets directive is required";
     else if ((mesid == 809) && (Lang == PL_UTF8)) message = "Przekroczono dopuszczalną liczbę uruchomionych sekcji";
@@ -266,43 +266,45 @@ std::string Logger::getErrorMessage(int mesid)
     else if ((mesid == 813) && (Lang == PL_UTF8)) message = "Przekroczono dopuszczalną liczbę uruchomionych klas";
     else if ((mesid == 813) && (Lang == EN)) message = "Allowed classes number exceeded";
     else if ((mesid == 814) && (Lang == PL_UTF8)) message = "Klasa typu wrapper wymaga parametru rate";
-    else if ((mesid == 814) && (Lang == EN)) message = "Wrapper class requires rate parameter";
+    else if ((mesid == 814) && (Lang == EN)) message = "Wrapper class requires the rate parameter";
+    else if ((mesid == 815) && (Lang == PL_UTF8)) message = "Host w uproszczonej postaci wymaga skonfigurowanej dyrektywy auto-hosts";
+    else if ((mesid == 815) && (Lang == EN)) message = "Simplified host requires the auto-hosts directive to be configured";
     else if ((mesid == 850) && (Lang == PL_UTF8)) message = "Błąd składni";
     else if ((mesid == 850) && (Lang == EN)) message = "Syntax error";
     else if ((mesid == 851) && (Lang == PL_UTF8)) message = "Makra dozwolone są wyłącznie w plikach klas";
-    else if ((mesid == 851) && (Lang == EN)) message = "Macros valid inside class files only";
+    else if ((mesid == 851) && (Lang == EN)) message = "Macros are valid inside the classes files only";
     else if ((mesid == 852) && (Lang == PL_UTF8)) message = "Include jest zabronione wewnątrz makra";
     else if ((mesid == 852) && (Lang == EN)) message = "Include inside a macro is illegal";
     else if ((mesid == 853) && (Lang == PL_UTF8)) message = "Zagnieżdzanie makr jest zabronione";
     else if ((mesid == 853) && (Lang == EN)) message = "Macro inside another macro is illegal";
     else if ((mesid == 854) && (Lang == PL_UTF8)) message = "Przetworzenie makra zakończone niepowodzeniem";
-    else if ((mesid == 854) && (Lang == EN)) message = "Proceed macro failed";
+    else if ((mesid == 854) && (Lang == EN)) message = "Macro proceeding failed";
     else if ((mesid == 855) && (Lang == PL_UTF8)) message = "Niepoprawne wartości parametrów makra";
-    else if ((mesid == 855) && (Lang == EN)) message = "Bad macro parameters";
+    else if ((mesid == 855) && (Lang == EN)) message = "Bad macro's parameters";
     else if ((mesid == 856) && (Lang == PL_UTF8)) message = "Niepoprawny typ makra";
     else if ((mesid == 856) && (Lang == EN)) message = "Bad macro type";
     else if ((mesid == 857) && (Lang == PL_UTF8)) message = "Niepoprawna liczba parametrów makra";
-    else if ((mesid == 857) && (Lang == EN)) message = "Bad number of parameters";
+    else if ((mesid == 857) && (Lang == EN)) message = "Bad number of macro's parameters";
     else if ((mesid == 858) && (Lang == PL_UTF8)) message = "Niedozwolony lub zdublowany parametr _classid_, _filterid_ lub _set-mark_";
-    else if ((mesid == 858) && (Lang == EN)) message = "illegal or duplicated parameter _classid_ or _filterid_ or _set-mark_";
+    else if ((mesid == 858) && (Lang == EN)) message = "Illegal or duplicated parameter _classid_ or _filterid_ or _set-mark_";
     else if ((mesid == 859) && (Lang == PL_UTF8)) message = "Zdublowany parametr mark lub set-mark";
-    else if ((mesid == 859) && (Lang == EN)) message = "mark or set-mark parameter duplicated";    
+    else if ((mesid == 859) && (Lang == EN)) message = "The mark or set-mark parameter duplicated";    
     else if ((mesid == 860) && (Lang == PL_UTF8)) message = "Parametr set-mark filtra jest niedozwolony (wycofany)";
-    else if ((mesid == 860) && (Lang == EN)) message = "parameter set-mark in filter is illegal (deprecated)";    
+    else if ((mesid == 860) && (Lang == EN)) message = "Parameter set-mark in filter is illegal (deprecated)";    
     else if ((mesid == 861) && (Lang == PL_UTF8)) message = "Parametr match sekcji jest niedozwolony (wycofany) i zastąpiony przez local-subnets sekcji global";
-    else if ((mesid == 861) && (Lang == EN)) message = "parameter match in functional section is illegal (deprecated) and superseded by local-subnets within global section";
+    else if ((mesid == 861) && (Lang == EN)) message = "Parameter match in functional section is illegal (deprecated) and superseded by local-subnets within global section";
     else if ((mesid == 862) && (Lang == PL_UTF8)) message = "Wartość parametru set-mark nie może się powtarzać";
-    else if ((mesid == 862) && (Lang == EN)) message = "Value of set-mark parameter can't be repeated";    
-    else if ((mesid == 863) && (Lang == PL_UTF8)) message = "Nazwy klas muszą być unikalne w ramach sekcji. Duplikat";
-    else if ((mesid == 863) && (Lang == EN)) message = "Class name within section must be unique. Duplicate";
+    else if ((mesid == 862) && (Lang == EN)) message = "Value of set-mark parameter must not be repeated";    
+    else if ((mesid == 863) && (Lang == PL_UTF8)) message = "Nazwy klas muszą być unikalne w ramach sekcji. Wykryto duplikat";
+    else if ((mesid == 863) && (Lang == EN)) message = "Classes names within the section must be unique. Duplicate detected";
     else if ((mesid == 864) && (Lang == PL_UTF8)) message = "Klasa typu virtual nie współpracuje z interfejsami IMQ";
     else if ((mesid == 864) && (Lang == EN)) message = "Virtual class doesn't work with IMQ interfaces";
     else if ((mesid == 865) && (Lang == PL_UTF8)) message = "Test to-local wymaga interfejsu IMQ, gdyż ingress shaping nie jest obsługiwany";
     else if ((mesid == 865) && (Lang == EN)) message = "To-local test requires IMQ interface, because ingress shaping is not supported";
-    else if ((mesid == 866) && (Lang == PL_UTF8)) message = "Interfejs sieciowy nie może być współdzielony przez klasy pracujące w trybie download z klasami upload";
+    else if ((mesid == 866) && (Lang == PL_UTF8)) message = "Interfejs sieciowy nie może być współdzielony przez klasy pracujące w trybie download z klasami w trybie upload";
     else if ((mesid == 866) && (Lang == EN)) message = "Network interface can't share both download mode and upload mode classes";
     else if ((mesid == 867) && (Lang == PL_UTF8)) message = "Klasy typów wrapper oraz do-not-shape, jeśli występują samodzielnie na interfejsie (to znaczy, bez towarzystwa klas standardowych), wymagają wskazania kierunku przepływu kontrolowanego na tym interfejsie ruchu. Użyj parametru iface-<dev> mode download|upload";
-    else if ((mesid == 867) && (Lang == EN)) message = "The wrapper and do-not-shape classes, if work alone on interface (it means, not together with standard classes), require to set the flow direction of traffic controlled on this interface. Use iface-<dev> mode download|upload parameter";
+    else if ((mesid == 867) && (Lang == EN)) message = "The wrapper and do-not-shape classes, if work alone on the interface (it means, not together with standard classes), require to set the flow direction of traffic controlled on this interface. Use iface-<dev> mode download|upload parameter";
     // Internal errors
     else if ((mesid == 998) && (Lang == PL_UTF8)) message = "Błąd wewnętrzny. Nie można było ustalić trybu klasy";
     else if ((mesid == 998) && (Lang == EN)) message = "Internal error. Can't determine class mode";
@@ -324,13 +326,13 @@ std::string Logger::getWarningMessage (int mesid)
 //    else if (( mesid == 2 ) && ( Lang == PL_UTF8 )) message = "Uzyto niestandardowego łańcucha iptables";
 //    else if (( mesid == 2 ) && ( Lang == EN )) message = "Probably wrong iptables hook";
     else if (( mesid == 3 ) && ( Lang == PL_UTF8 )) message = "Brak parametru download-section, użyto wartości domyślnej";
-    else if (( mesid == 3 ) && ( Lang == EN )) message = "Missing download-section parameter, using default";
+    else if (( mesid == 3 ) && ( Lang == EN )) message = "Missing download-section parameter, using default value";
     else if (( mesid == 4 ) && ( Lang == PL_UTF8 )) message = "Brak parametru upload-section, użyto wartości domyślnej";
-    else if (( mesid == 4 ) && ( Lang == EN )) message = "Missing upload-section parameter, using default";
+    else if (( mesid == 4 ) && ( Lang == EN )) message = "Missing upload-section parameter, using default value";
     else if (( mesid == 5 ) && ( Lang == PL_UTF8 )) message = "Brak parametru, użyto wartości domyślnej";
-    else if (( mesid == 5 ) && ( Lang == EN )) message = "Missing parameter, using default";
+    else if (( mesid == 5 ) && ( Lang == EN )) message = "Missing parameter, using default value";
     else if (( mesid == 6 ) && ( Lang == PL_UTF8 )) message = "Brak parametru, klasy nie zostaną utworzone";
-    else if (( mesid == 6 ) && ( Lang == EN )) message = "Missing parameter, not attempt to generate classess";
+    else if (( mesid == 6 ) && ( Lang == EN )) message = "Missing parameter, omit attempt to generate classes";
 //    else if (( mesid == 7 ) && ( Lang == PL_UTF8 )) message = "Podana opcja jest przestarzała, użyj iptables hook";
 //    else if (( mesid == 7 ) && ( Lang == EN )) message = "Given option is deprecated, use iptables hook instead";
     else if (( mesid == 11 ) && ( Lang == PL_UTF8 )) message = "Aliasy interfejsów nie są rozróżniane";
@@ -340,15 +342,15 @@ std::string Logger::getWarningMessage (int mesid)
     else if (( mesid == 13 ) && ( Lang == PL_UTF8 )) message = "Błędna jednostka quoty, zostanie użyte MB";
     else if (( mesid == 13 ) && ( Lang == EN )) message = "Wrong quota unit, using MB instead";
     else if (( mesid == 14 ) && (Lang == PL_UTF8)) message = "Liczniki wyzwalacza quota nie będą zapisywane a inicjalizacja reguł iptables, przechodzi w znacznie wolniejszy tryb fallback! Brakujący ważny katalog";
-    else if (( mesid == 14 ) && (Lang == EN)) message = "Quota counters will be lost after restart and iptables initialization switch to fallkback mode thus will be much slower! Missing important directory";
-    else if (( mesid == 15 ) && (Lang == PL_UTF8)) message = "iptables-restore nie zostanie użyty! Nie można utworzyc pliku";
-    else if (( mesid == 15 ) && (Lang == EN)) message = "iptables-restore will not be used! Cannot create file";
-    else if (( mesid == 16 ) && (Lang == PL_UTF8)) message = "Tryb szybkiego startu nie zostanie uzyty! Brak wymaganego pliku binarnego iptables-save";
-    else if (( mesid == 16 ) && (Lang == EN)) message = "Fallback to slow start! Missing required iptables-save executable";
-    else if (( mesid == 17 ) && (Lang == PL_UTF8)) message = "Tryb szybkiego startu nie zostanie uzyty! Brak wymaganego pliku binarnego iptables-restore";
-    else if (( mesid == 17 ) && (Lang == EN)) message = "Fallback to slow start! Missing required iptables-restore executable";
+    else if (( mesid == 14 ) && (Lang == EN)) message = "Quota counters will be lost after restart. Iptables initialization switched to fallback mode, thus will be much slower! Missing important directory";
+    else if (( mesid == 15 ) && (Lang == PL_UTF8)) message = "Polecenie iptables-restore nie zostanie użyte! Nie można utworzyć pliku";
+    else if (( mesid == 15 ) && (Lang == EN)) message = "The iptables-restore command won't be used! Can't create file";
+    else if (( mesid == 16 ) && (Lang == PL_UTF8)) message = "Tryb szybkiego startu nie zostanie użyty! Brak wymaganego pliku binarnego iptables-save";
+    else if (( mesid == 16 ) && (Lang == EN)) message = "Fallback to slow start method! Missing required iptables-save executable";
+    else if (( mesid == 17 ) && (Lang == PL_UTF8)) message = "Tryb szybkiego startu nie zostanie użyty! Brak wymaganego pliku binarnego iptables-restore";
+    else if (( mesid == 17 ) && (Lang == EN)) message = "Fallback to slow start method! Missing required iptables-restore executable";
     else if (( mesid == 18 ) && ( Lang == PL_UTF8 )) message = "Dyrektywa oraz komenda stats są przestarzałe i zastąpione przez status";
-    else if (( mesid == 18 ) && ( Lang == EN )) message = "The stats directive and command are deprecated, use status instead";
+    else if (( mesid == 18 ) && ( Lang == EN )) message = "The stats directives and command are deprecated, use status instead";
     else if ( Lang == PL_UTF8 ) message = "Nieznane ostrzeżenie";
     else message = "Unknown warning";
 
@@ -385,6 +387,8 @@ std::string Logger::getInfoMessage (int mesid)
     else if (( mesid == 12 ) && ( Lang == EN )) message = "Starting recovery procedure";
     else if (( mesid == 13 ) && ( Lang == PL_UTF8 )) message = "Procedura odzyskiwania zakończona sukcesem";
     else if (( mesid == 13 ) && ( Lang == EN )) message = "Recovery procedure proceeded successfully";
+    else if (( mesid == 45 ) && ( Lang == PL_UTF8 )) message = "NiceShaper nie jest uruchomiony";
+    else if (( mesid == 45 ) && ( Lang == EN )) message = "NiceShaper is not running";
     // 
     else if (( mesid == 100 ) && ( Lang == PL_UTF8 )) message = "Ze względu na użytą dyrektywę debug iptables, plik inicjujący reguły iptables nie zostanie usunięty";
     else if (( mesid == 100 ) && ( Lang == EN )) message = "Iptables initialization script won't be removed because of debug iptables directive";
@@ -543,7 +547,7 @@ void Logger::dumpHelp()
     onTerminal ( "  --confdir </path>          - overwrite configuration directory location   ");
     onTerminal ( "  --conffile <path>          - overwrite configuration file path            ");
     onTerminal ( "  --classfile <path>         - overwrite classes file path                  ");
-    onTerminal ( "  --no-daemon                - don't move a process into the background     ");
+    onTerminal ( "  --no-daemon                - don't move the process into the background   ");
     onTerminal ( "                                                                            ");
     onTerminal ( "  status|show - remote niceshaper access options:                           ");
     onTerminal ( "  --remote <ip[:port]>       - connect to remote NiceShaper                 ");
