@@ -96,7 +96,9 @@ int main(int argc, char *argv[])
     runtime_cmd = runtime_params.at(1);
 
     // Get command line parameters
-    if (read_cmdline_params (runtime_params, runtime_param_daemon_mode, runtime_param_remote_address, runtime_param_remote_password, runtime_param_status_unit, runtime_param_status_watch, runtime_param_show_running) == -1) exit(-1);
+    if (read_cmdline_params (runtime_params, runtime_param_daemon_mode, runtime_param_remote_address, runtime_param_remote_password, runtime_param_status_unit, runtime_param_status_watch, runtime_param_show_running) == -1) {
+        exit(-1);
+    }
 
     if ((getuid() != 0) && (geteuid() != 0) && !((runtime_cmd == "status") && (runtime_param_remote_address.size()))) {
         log->error(404);
@@ -112,7 +114,9 @@ int main(int argc, char *argv[])
     // Read configuration
     if (config->convertToFpv (confdir, conffile, CONFTYPE, fpv_conffile) == -1) exit (-1);
 
-    if (proceed_global_config(fpv_conffile) == -1) exit (-1);
+    if (proceed_global_config(fpv_conffile) == -1) {
+        if ((runtime_cmd != "status") && (runtime_cmd != "stats") && (runtime_cmd != "show") && (runtime_cmd != "stop")) exit (-1);
+    }
 
     if (config->removeConfTypeGarbage (fpv_conffile) == -1) exit (-1);
 
@@ -212,8 +216,6 @@ int controller(std::string runtime_cmd, std::string runtime_param_remote_address
 
     log->setLogOnTerminal(true);
 
-    if (!test->fileExists(pidfile)) { log->error(45); return -1;  }
-
     if ((runtime_cmd == "status") || (runtime_cmd == "stats") || (runtime_cmd == "show")) 
     {
         talk = new Talk;
@@ -227,6 +229,8 @@ int controller(std::string runtime_cmd, std::string runtime_param_remote_address
             request += " --password " + runtime_param_remote_password;
         }
         else {
+            if (!test->fileExists(pidfile)) { log->error(45); return -1;  }
+
             // Get listen address and password
             ifd.open(svinfofile.c_str());
             if (ifd.is_open()) {
@@ -289,6 +293,15 @@ int controller(std::string runtime_cmd, std::string runtime_param_remote_address
     }
     else if ((runtime_cmd == "stop") || (runtime_cmd == "restart"))
     {
+        if (!test->fileExists(pidfile)) { 
+            if (runtime_cmd == "restart") {
+                log->onTerminal (log->getInfoMessage(45));
+                return 0;
+            }
+            log->error(45); 
+            return -1;  
+        }
+
         // Get supervisor pid
         ifd.open(pidfile.c_str());
         if (!ifd) { log->error(45); return -1;  }
@@ -401,19 +414,20 @@ int proceed_global_config (std::vector <std::string> &fpv_conffile)
         param = aux::awk(*fpvi, 2);
         value = aux::awk(*fpvi, 3);
 
-        if ( option == "run" ) {
+        if (option == "run") {
             if (param.size() > MAX_SECTION_NAME_SIZE) { log->error(54, *fpvi); return -1; }
             config->addRunningSection(param);
             if (config->RunningSections.size() > MAX_SECTIONS_COUNT) { log->error(809, aux::int_to_str(MAX_SECTIONS_COUNT)); return -1; }
         }
         else if (option == "mark-on-ifaces") 
         {
-            param = aux::trim_dev(param);
-            if (!ifaces->isValidSysDev(param)) { log->error (16, *fpvi); return -1; }
-            ifaces->setTcFilterType(param, FW);
+            dev = aux::trim_dev(param);
+            if (!ifaces->isValidSysDev(dev)) { log->error (16, *fpvi); return -1; }
+            ifaces->setTcFilterType(dev, FW);
         }
-        else if ((aux::awk(option, "-", 1) == "iface") && (ifaces->isValidSysDev(aux::awk(option, "-", 2)))) {
-            dev = aux::awk(option, "-", 2);
+        else if (aux::awk(option, "-", 1) == "iface") {
+            dev = aux::trim_dev(option.substr(option.find("-")+1, std::string::npos));
+            if (!ifaces->isValidSysDev(dev)) { log->error (16, *fpvi); return -1; }
             if (param == "speed") {
                 if ((aux::unit_convert(value, BITS) > MAX_RATE) || (aux::unit_convert(value, BITS) < MIN_RATE)) { log->error(806, *fpvi); return -1; }
                 ifaces->setSpeed(dev, aux::unit_convert(value, BITS));
@@ -586,6 +600,12 @@ int proceed_global_config (std::vector <std::string> &fpv_conffile)
         {
             if (config->addLocalSubnet(param) == -1) { log->error(59, *fpvi); return -1; }
         }
+        else if (option == "auto-hosts") {
+            if (param.size() > MAX_SECTION_NAME_SIZE) { log->error(54, *fpvi); return -1; }
+            dev = aux::trim_dev(value);
+            if (!ifaces->isValidSysDev(dev)) { log->error (16, *fpvi); return -1; }
+            config->addAutoHostsBasis(param, dev);
+        }
 
         fpvi++;
     }
